Learn R Programming

arakno (version 1.3.1)

species: Get species from higher taxa.

Description

Get species within given families or genera from the World Spider Catalogue.

Usage

species(tax, order = FALSE)

Value

A vector with species names.

Arguments

tax

A taxon name or vector with taxa names.

order

Order species names alphabetically.

Details

This function will get all species currently listed for given families or genera from the World Spider Catalogue (2025).

References

World Spider Catalog (2025). World Spider Catalog. Version 26. Natural History Museum Bern, online at http://wsc.nmbe.ch. doi: 10.24436/2.

Examples

Run this code
if (FALSE) {
species("Amphiledorus")
species(tax = c("Amphiledorus", "Nemesiidae"), order = TRUE)
}

Run the code above in your browser using DataLab