powered by
Get species within given families or genera from the World Spider Catalogue.
species(tax, order = FALSE)
A vector with species names.
A taxon name or vector with taxa names.
Order species names alphabetically.
This function will get all species currently listed for given families or genera from the World Spider Catalogue (2025).
World Spider Catalog (2025). World Spider Catalog. Version 26. Natural History Museum Bern, online at http://wsc.nmbe.ch. doi: 10.24436/2.
if (FALSE) { species("Amphiledorus") species(tax = c("Amphiledorus", "Nemesiidae"), order = TRUE) }
Run the code above in your browser using DataLab